# pvm.tcl --
#
# Initialization script normally executed in the interpreter for each
# TkPvm-based application.
#

# Insist on running with compatible versions of Tcl and Pvm

scan [info tclversion] "%d.%d" a b
if {$a != 7} {
    error "wrong version of Tcl loaded ([info tclversion]): need 7.x"
}
scan $tkpvm_version "%d.%d" a b
if {($a != 1) || ($b < 0)} {
    error "wrong version of tkPvm loaded ($tkpvm_version): need 1.x"
}
unset a b

# Add tkPvm's directory to the end of the auto-load search path.
#
    lappend auto_path $tkpvm_library

# Rename "send" to "tk_send",
#        "bind" to "tk_bind", and
#        "exit" to "tk_exit", if possible.
#
if {[info command send]==""} {
    proc send {args} {
	error "expected integer but got \"[lindex $args 1]\""
    }
}
if {[info command bind]==""} {
    proc bind {args} {
	error "expected integer or one of the keywords\
\"any\" or \"kill\" but got \"[lindex $args 1]\""
    }
}
if {[info command tk_send]==""} {
    rename send tk_send
}
if {[info command tk_bind]==""} {
    rename bind tk_bind
}
if {[info command tk_exit]==""} {
    rename exit tk_exit
}

# Replacements for send, bind and exit.
#
proc send {args} {
    set msgtag [lindex $args 1]
    if {$msgtag=="" || [catch {expr [expr $msgtag].0} ]} {
	return [eval tk_send $args]
    } else {
	return [eval pvm send $args]
    }
}

proc bind {args} {
    set msgtag [lindex $args 1]
    if {$msgtag!="any" && $msgtag!="kill" && ($msgtag=="" || [catch {expr [expr $msgtag].0} ])} {
	return [eval tk_bind $args]
    } else {
	return [eval pvm bind $args]
    }
}

proc exit {{error 0}} {
    pvm exit
    tk_exit $error
}
